#!/bin/bash
################################################################################
# Intended use: Simple shell script to create certs (RSA or EC)
#
# Notes: This script support Linux Bash shell script only
# Install Bash from https://www.gnu.org/software/bash/
#
# Copyright (C) 2015 - 2023, VGISC Dev Team <dev@vgisc.com>
################################################################################

filepath=`readlink -f $0`
SCRIPT_DIR=`dirname $filepath`
basedir=$SCRIPT_DIR/..
FLAG_EC=0

DEV_SRC_DIR="/vgisc/6t/CT129/Dev"
OPENSSL_BIN="$DEV_SRC_DIR/BML/src/rls/3.3.2/rootfs/opt/vgisc/usr/linux-x86_64/bin/openssl"
OPENSSL_LIB="$DEV_SRC_DIR/BML/src/rls/3.3.2/rootfs/opt/vgisc/usr/linux-x86_64/lib"
TEST_OPENSSL_BIN="$OPENSSL_BIN"
COMMON_ARGS="-batch"
export LD_LIBRARY_PATH="$OPENSSL_LIB:$LD_LIBRARY_PATH"

ROOT_CA_DIR="$basedir/root-ca"
SUB_CA_DIR="$basedir/sub-ca"
SERVER_DIR="$basedir/server"
SERVER_DIR="$basedir/server"
CLIENT_DIR="$basedir/client"
DEST_DOMAIN="vgisc.com"
DEST_DIR="$basedir/${DEST_DOMAIN}"

echo ""
echo "========================================================================="
echo "Generating RSA certs/keys for ${DEST_DOMAIN}..."
echo "========================================================================="
echo ""

echo "Generating Root CA certificate to ${DEST_DIR}/..."
if [[ (! -f ${ROOT_CA_DIR}/root-ca.crt) || (! -f ${ROOT_CA_DIR}/sub-ca.crt) ]]
then
	${SCRIPT_DIR}/gen_rsa_ca-3.3.2.sh
fi
mkdir -p ${DEST_DIR}
cp -rf ${ROOT_CA_DIR}/root-ca.crt ${DEST_DIR}/ca.${DEST_DOMAIN}.crt
cp -rf ${SUB_CA_DIR}/sub-ca.crt ${DEST_DIR}/sub-ca.${DEST_DOMAIN}.crt

echo "Generating all server keys/certs to ${DEST_DIR}/..."
if [[ (! -f ${SERVER_DIR}/server-1.${DEST_DOMAIN}.crt) || (! -f ${SERVER_DIR}/server-1.${DEST_DOMAIN}.key) ]]
then
	${SCRIPT_DIR}/gen_rsa_servers-3.3.2.sh
fi
cp -rf ${SERVER_DIR}/*.key ${DEST_DIR}/
cp -rf ${SERVER_DIR}/*.crt ${DEST_DIR}/

echo "Generating all client keys/certs to ${DEST_DIR}/..."
if [[ (! -f ${CLIENT_DIR}/client-1.${DEST_DOMAIN}.crt) || (! -f ${CLIENT_DIR}/client-1.${DEST_DOMAIN}.key) ]]
then
	${SCRIPT_DIR}/gen_rsa_clients-3.3.2.sh
fi
cp -rf ${CLIENT_DIR}/*.key ${DEST_DIR}/
cp -rf ${CLIENT_DIR}/*.crt ${DEST_DIR}/
    
echo "All keys/certs are saved to ${DEST_DIR}/..."
ls -la ${DEST_DIR}/
echo "All Done."
################################################################################
#					BASH SCRIPT ON LINUX/UNIX - END
################################################################################
